==> haskell-filemanip-0.3.6.3-279-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filemanip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filemanip
version:              0.3.6.3
visibility:           public
id:                   filemanip-0.3.6.3-3FYwU7ByNV4CdahD4NAApI
key:                  filemanip-0.3.6.3-3FYwU7ByNV4CdahD4NAApI
license:              BSD-3-Clause
maintainer:           Bryan O'\''Sullivan
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/bos/filemanip
synopsis:             Expressive file and directory manipulation for Haskell.
description:
    A Haskell library for working with files and directories.
    Includes code for pattern matching, finding files,
    modifying file contents, and more.

category:             System
abi:                  6e044a310a0f16bbd6591b20b86f7c97
exposed:              True
exposed-modules:
    System.FilePath.Find System.FilePath.Glob
    System.FilePath.GlobPattern System.FilePath.Manip

import-dirs:          /usr/lib/ghc-9.6.6/site-local/filemanip-0.3.6.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/filemanip-0.3.6.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/filemanip-0.3.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filemanip
hs-libraries:         HSfilemanip-0.3.6.3-3FYwU7ByNV4CdahD4NAApI
depends:
    base-4.18.2.1 bytestring-0.11.5.3 directory-1.3.8.5
    filepath-1.4.300.1 mtl-2.3.1
    unix-compat-0.7.4.1-6OqqpjAelUgGQ8Q8qYmpdb

haddock-interfaces:   /usr/share/doc/haskell-filemanip/html/filemanip.haddock
haddock-html:         /usr/share/doc/haskell-filemanip/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-filemanip-0.3.6.3-280-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filemanip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filemanip
version:              0.3.6.3
visibility:           public
id:                   filemanip-0.3.6.3-GHRKOvnd3oE5qcJG4OXDTg
key:                  filemanip-0.3.6.3-GHRKOvnd3oE5qcJG4OXDTg
license:              BSD-3-Clause
maintainer:           Bryan O'\''Sullivan
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/bos/filemanip
synopsis:             Expressive file and directory manipulation for Haskell.
description:
    A Haskell library for working with files and directories.
    Includes code for pattern matching, finding files,
    modifying file contents, and more.

category:             System
abi:                  3aabb5cbeac39aae63d62bb9b9faafd4
exposed:              True
exposed-modules:
    System.FilePath.Find System.FilePath.Glob
    System.FilePath.GlobPattern System.FilePath.Manip

import-dirs:          /usr/lib/ghc-9.6.6/site-local/filemanip-0.3.6.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/filemanip-0.3.6.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/filemanip-0.3.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filemanip
hs-libraries:         HSfilemanip-0.3.6.3-GHRKOvnd3oE5qcJG4OXDTg
depends:
    base-4.18.2.1 bytestring-0.11.5.3 directory-1.3.8.5
    filepath-1.4.300.1 mtl-2.3.1
    unix-compat-0.7.4.1-Isq1lnRC0mk6kwUSQt5zkJ

haddock-interfaces:   /usr/share/doc/haskell-filemanip/html/filemanip.haddock
haddock-html:         /usr/share/doc/haskell-filemanip/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
